@@ -1,43 +1,29 @@
-import random
 from typing import Optional
-
 import requests
-
 from image_depot import DepotType
 from .base import Depot
 
-TOKEN = ''
-EMAIL = ''
-PASSWORD = ''
-
-
-def set_config(email: str, password: str):
-    """
-    :param email:
-    :param password:
-    :return:
-    """
-    global EMAIL, PASSWORD
-    EMAIL = email
-    PASSWORD = password
-
 
 class Xywm(Depot):
+    def __init__(self):
+        super().__init__()
+        self._token = None
+
     @classmethod
     def depot_type(cls) -> DepotType:
         return DepotType.Xywm
 
     def _upload(self, content) -> Optional[str]:
-        global TOKEN
+        conf = self._config.xywm
         # 若存在用户名和密码, 获取 token
-        if not TOKEN and EMAIL and PASSWORD:
+        if not self._token and conf.email and conf.password:
             data = {
-                'email': EMAIL,
-                'password': PASSWORD
+                'email': conf.email,
+                'password': conf.password
             }
             response = requests.post("https://pic.xywm.ltd/api/v1/tokens", data=data)
             if response.status_code == 200:
-                TOKEN = response.json().get('data', {}).get('token')
+                self._token = response.json().get('data', {}).get('token')
 
         # 上传图片
         tmp_filename = self._random_file_name(content)
@@ -49,8 +35,8 @@ class Xywm(Depot):
         headers = {
             "Accept": "application/json",
         }
-        if TOKEN:
-            headers['Authorization'] = f'Bearer {TOKEN}'
+        if self._token:
+            headers['Authorization'] = f'Bearer {self._token}'
         response = requests.post("https://pic.xywm.ltd/api/v1/upload", headers=headers, files=files)
         if response.status_code != 200:
             return self._set_error(f'upload fail. code: {response.status_code}')
